Utility Modules
===============

Shared helpers for data shaping, text handling, numeric operations, and
substitutions.

.. autosummary::
   :toctree: generated

   etlplus.utils.data
   etlplus.utils.mapping
   etlplus.utils.mixins
   etlplus.utils.numbers
   etlplus.utils.substitution
   etlplus.utils.text
   etlplus.utils.types
